@@ -15,23 +15,16 @@ _build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '{BUILDROOT}/bin',
  'BINLIBDEST': '{BUILDROOT}/lib/python3.10',
  'BLDLIBRARY': 'libpython3.10.a',
- 'BLDSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -no-pie -pthread -shared '
-              '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-              '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-              '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++ '
-              '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-              '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-              '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++',
+ 'BLDSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread -shared '
+              '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
+              '-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -no-pie -pthread',
+ 'CC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
-           '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
-           '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
-           '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
            '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
            '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
@@ -50,10 +43,9 @@ _build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                        '-I{BUILDROOT}/include/ncursesw '
                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
- 'CONFIGURE_LDFLAGS': '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-                      '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-                      '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib '
-                      '-static-libstdc++',
+ 'CONFIGURE_LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
+                      '-L{BUILDROOT}/lib '
+                      '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
  'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition',
  'CONFIG_ARGS': "'-v' '--prefix={BUILDROOT}' '--with-openssl={BUILDROOT}' "
                 "'--enable-optimizations' '--with-ensurepip=no' "
@@ -63,13 +55,12 @@ _build_time_vars = {'ABIFLAGS': '',
                 "'--with-readline=readline' '--with-pkg-config=yes' "
                 "'ac_cv_file__dev_ptmx=yes' 'ac_cv_file__dev_ptc=no' "
                 "'build_alias=x86_64-linux-gnu' 'host_alias=x86_64-linux-gnu' "
-                "'CC={TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -no-pie' "
+                "'CC={TOOLCHAIN}/bin/x86_64-linux-gnu-gcc' "
                 "'CFLAGS=-Wno-coverage-mismatch -g -I{BUILDROOT}/include "
                 '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
                 "-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include' "
-                "'LDFLAGS=-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 "
-                '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-                "-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++' "
+                "'LDFLAGS=-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib "
+                "-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib' "
                 "'CPPFLAGS=-I{BUILDROOT}/include "
                 '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
                 "-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include' "
@@ -77,17 +68,14 @@ _build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '{BUILDROOT}/include',
  'CONFINCLUDEPY': '{BUILDROOT}/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/runner/work/relenv/relenv/src/Python-3.10.15/coverage.info',
- 'COVERAGE_REPORT': '/home/runner/work/relenv/relenv/src/Python-3.10.15/lcov-report',
+ 'COVERAGE_INFO': '/home/runner/work/relenv/relenv/src/Python-3.10.17/coverage.info',
+ 'COVERAGE_REPORT': '/home/runner/work/relenv/relenv/src/Python-3.10.17/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I{BUILDROOT}/include '
              '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
-             '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-             '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
-             '-I{BUILDROOT}/include/ncursesw '
              '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
- 'CXX': '{TOOLCHAIN}/bin/x86_64-linux-gnu-g++ -no-pie -pthread',
+ 'CXX': '{TOOLCHAIN}/bin/x86_64-linux-gnu-g++ -pthread',
  'DESTDIRS': '{BUILDROOT} {BUILDROOT}/lib {BUILDROOT}/lib/python3.10 '
              '{BUILDROOT}/lib/python3.10/lib-dynload',
  'DESTLIB': '{BUILDROOT}/lib/python3.10',
@@ -573,22 +561,14 @@ _build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.10.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-g++ -no-pie -pthread -shared',
- 'LDFLAGS': '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-            '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-            '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++ '
-            '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-            '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-            '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++',
+ 'LDCXXSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-g++ -pthread -shared',
+ 'LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
+            '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
  'LDLIBRARY': 'libpython3.10.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -no-pie -pthread -shared '
-             '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-             '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-             '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++ '
-             '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-             '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-             '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++',
+ 'LDSHARED': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread -shared '
+             '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
+             '-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
  'LDVERSION': '3.10',
  'LIBC': '',
  'LIBDEST': '{BUILDROOT}/lib/python3.10',
@@ -606,7 +586,7 @@ _build_time_vars = {'ABIFLAGS': '',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
  'LIBSUBDIRS': 'asyncio \\',
- 'LINKCC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -no-pie -pthread',
+ 'LINKCC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -619,7 +599,7 @@ _build_time_vars = {'ABIFLAGS': '',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '{BUILDROOT}/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -no-pie -pthread',
+ 'MAINCC': '{TOOLCHAIN}/bin/x86_64-linux-gnu-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
@@ -653,7 +633,7 @@ _build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '-L{BUILDROOT}/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -g  -O3 -Wall',
+ 'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -687,16 +667,12 @@ _build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2,md5,sha1,sha2,sha3"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  '
-                             '-O3 -Wall -Wno-coverage-mismatch -g '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
+                             '-fwrapv -O3 -Wall -Wno-coverage-mismatch -g '
                              '-I{BUILDROOT}/include '
                              '-I{BUILDROOT}/include/readline '
                              '-I{BUILDROOT}/include/ncursesw '
                              '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-                             '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
-                             '-I{BUILDROOT}/include/readline '
-                             '-I{BUILDROOT}/include/ncursesw '
-                             '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                              '-fno-semantic-interposition -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
@@ -706,15 +682,8 @@ _build_time_vars = {'ABIFLAGS': '',
                              '-I{BUILDROOT}/include/readline '
                              '-I{BUILDROOT}/include/ncursesw '
                              '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-                             '-I{BUILDROOT}/include '
-                             '-I{BUILDROOT}/include/readline '
-                             '-I{BUILDROOT}/include/ncursesw '
-                             '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
-              '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
-              '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
-              '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
               '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
               '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
@@ -723,12 +692,8 @@ _build_time_vars = {'ABIFLAGS': '',
                      '-Wno-missing-field-initializers -fvisibility=hidden '
                      '-fprofile-use -fprofile-correction -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 -Wall '
-                   '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
-                   '-I{BUILDROOT}/include/readline '
-                   '-I{BUILDROOT}/include/ncursesw '
-                   '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-                   '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
+                   '-Wall -Wno-coverage-mismatch -g -I{BUILDROOT}/include '
                    '-I{BUILDROOT}/include/readline '
                    '-I{BUILDROOT}/include/ncursesw '
                    '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
@@ -740,42 +705,24 @@ _build_time_vars = {'ABIFLAGS': '',
                    '-I{BUILDROOT}/include/readline '
                    '-I{BUILDROOT}/include/ncursesw '
                    '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-                   '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
-                   '-I{BUILDROOT}/include/ncursesw '
-                   '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-                    '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-                    '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib '
-                    '-static-libstdc++ -Wl,--rpath={BUILDROOT}/lib '
-                    '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
+ 'PY_CORE_LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
                     '-L{BUILDROOT}/lib '
                     '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib '
-                    '-static-libstdc++ -fno-semantic-interposition',
+                    '-fno-semantic-interposition',
  'PY_CPPFLAGS': '-I. -I./Include -I{BUILDROOT}/include '
                 '-I{BUILDROOT}/include/readline -I{BUILDROOT}/include/ncursesw '
-                '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-                '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
-                '-I{BUILDROOT}/include/ncursesw '
                 '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
  'PY_ENABLE_SHARED': 0,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-               '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-               '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++ '
-               '-Wl,--rpath={BUILDROOT}/lib -Wl,--build-id=sha1 '
-               '-Wl,--rpath={BUILDROOT}/lib -L{BUILDROOT}/lib '
-               '-L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib -static-libstdc++',
+ 'PY_LDFLAGS': '-Wl,--build-id=sha1 -Wl,--rpath={BUILDROOT}/lib '
+               '-L{BUILDROOT}/lib -L{TOOLCHAIN}/x86_64-linux-gnu/sysroot/lib',
  'PY_LDFLAGS_NODIST': '-fno-semantic-interposition',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g  -O3 '
-                        '-Wall -Wno-coverage-mismatch -g -I{BUILDROOT}/include '
-                        '-I{BUILDROOT}/include/readline '
-                        '-I{BUILDROOT}/include/ncursesw '
-                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-                        '-Wno-coverage-mismatch -g -I{BUILDROOT}/include '
-                        '-I{BUILDROOT}/include/readline '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
+                        '-O3 -Wall -Wno-coverage-mismatch -g '
+                        '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                         '-I{BUILDROOT}/include/ncursesw '
                         '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
                         '-fno-semantic-interposition -std=c99 -Wextra '
@@ -785,9 +732,6 @@ _build_time_vars = {'ABIFLAGS': '',
                         '-I./Include/internal -I. -I./Include '
                         '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
                         '-I{BUILDROOT}/include/ncursesw '
-                        '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include '
-                        '-I{BUILDROOT}/include -I{BUILDROOT}/include/readline '
-                        '-I{BUILDROOT}/include/ncursesw '
                         '-I{TOOLCHAIN}/x86_64-linux-gnu/sysroot/usr/include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
@@ -868,8 +812,8 @@ _build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/runner/work/relenv/relenv/src/Python-3.10.15',
- 'abs_srcdir': '/home/runner/work/relenv/relenv/src/Python-3.10.15',
+ 'abs_builddir': '/home/runner/work/relenv/relenv/src/Python-3.10.17',
+ 'abs_srcdir': '/home/runner/work/relenv/relenv/src/Python-3.10.17',
  'datarootdir': '{BUILDROOT}/share',
  'exec_prefix': '{BUILDROOT}',
  'prefix': '{BUILDROOT}',
